@@ -1,6 +1,6 @@
 /*
      This file is part of GNUnet
-     (C) 2005, 2006 Christian Grothoff (and other contributing authors)
+     (C) 2005, 2006, 2007 Christian Grothoff (and other contributing authors)
 
      GNUnet is free software; you can redistribute it and/or modify
      it under the terms of the GNU General Public License as published
@@ -43,32 +43,29 @@
 #define DEBUG_END()
 #endif
 
-void initGNUnetGTKCommon(struct GE_Context * ectx,
-			 struct GC_Configuration * cfg,
-			 void * callback);
+void initGNUnetGTKCommon (struct GE_Context *ectx,
+                          struct GC_Configuration *cfg, void *callback);
 
-void shutdownPlugins(void);
+void shutdownPlugins (void);
 
-void doneGNUnetGTKCommon(void);
+void doneGNUnetGTKCommon (void);
 
 /**
  * Get the name of the main glade file for gnunet-gtk.
  */
-const char * getGladeFileName(void);
+const char *getGladeFileName (void);
 
 /**
  * Get the GladeXML for the main window of gnunet-gtk.
  */
-GladeXML * getMainXML(void);
+GladeXML *getMainXML (void);
 
 /**
  * Appends a message to the info window
  * @param doPopup if YES, the info window will
  *   be opened
  */
-void infoMessage(int doPopup,
-		 const char * format,
-		 ...);
+void infoMessage (int doPopup, const char *format, ...);
 
 /**
  * Appends a log entry to the info window
@@ -77,15 +74,16 @@ void infoMessage(int doPopup,
  *
  * @param txt the log entry
  */
-void addLogEntry(const char * txt, ...);
-	
+void addLogEntry (const char *txt, ...);
+
+struct GE_Context *createGtkLogger (GE_KIND mask);
+
 /**
  * Call a callback function from the mainloop/main thread ("SaveCall").
  * Since GTK doesn't work with multi-threaded applications under Windows,
  * all GTK operations have to be done in the main thread
  */
-void * gtkSaveCall(PThreadMain func,
-		   void * arg);
+void *gtkSaveCall (PThreadMain func, void *arg);
 
 /**
  * Run the given "cb" function and save calls
@@ -93,15 +91,14 @@ void * gtkSaveCall(PThreadMain func,
  * keep save calls going while something else
  * happens).
  */
-void * run_with_save_calls(PThreadMain cb,
-			   void * arg);
+void *run_with_save_calls (PThreadMain cb, void *arg);
 
 /**
  * Bind handlers defined by the various
  * plugins to the signals defined by the
  * Glade XML.
  */
-void connectGladeWithPlugins(GladeXML * xml);
+void connectGladeWithPlugins (GladeXML * xml);
 
 #define NOTIFY_LOW 0
 #define NOTIFY_NORMAL 1
@@ -110,30 +107,27 @@ void connectGladeWithPlugins(GladeXML * xml);
 /**
  * Sends a message to libnotify
  */
-void gnunetgtk_notify(int type,
-		      const char * message,
-		      ...);
+void gnunetgtk_notify (int type, const char *message, ...);
 
 /**
  * Validate that a string is a Utf-8 string.
  * If validation fails, msg is freed and a valid
  * Utf-8 string is returned.
  */
-char * validate_utf8(char * msg);
+char *validate_utf8 (char *msg);
 
 /**
-* Gtk callback to save the main window state (tray icon use)
-*/
-void saveMainWindowState(GtkWidget *main_window,
-                         GdkEventWindowState *event,
-                         gpointer user_data);
+ * Gtk callback to save the main window state (tray icon use)
+ */
+void saveMainWindowState (GtkWidget * main_window,
+                          GdkEventWindowState * event, gpointer user_data);
 
 /**
-* Get the last main window state when restoring (tray icon use)
-*/
-GdkWindowState getMainWindowState();
+ * Get the last main window state when restoring (tray icon use)
+ */
+GdkWindowState getMainWindowState (void);
 
-void gnunet_gtk_main_quit();
+void gnunet_gtk_main_quit (void);
 
 /**
 * Start gnunet-setup, asking for a password if needed
@@ -147,17 +141,19 @@ gboolean startGNUnetSetup (gboolean run_wizard);
  * except that modifications of the underlying model
  * during the iteration are tolerated.
  */
-void ggc_tree_selection_selected_foreach(GtkTreeSelection *selection,
-					 GtkTreeSelectionForeachFunc func,
-					 gpointer data);
+void ggc_tree_selection_selected_foreach (GtkTreeSelection * selection,
+                                          GtkTreeSelectionForeachFunc func,
+                                          gpointer data);
 
 /**
  * Identical to "gtk_tree_model_foreach",
  * except that modifications of the underlying model
  * during the iteration are tolerated.
  */
-void ggc_tree_model_foreach(GtkTreeModel * model,
-			    GtkTreeSelectionForeachFunc func,
-			    gpointer data);
+void ggc_tree_model_foreach (GtkTreeModel * model,
+                             GtkTreeSelectionForeachFunc func, gpointer data);
+
+
+struct CronManager *gnunet_gtk_get_cron (void);
 
 #endif
