@@ -29,13 +29,15 @@
 
 #include <GNUnet/gnunet_ecrs_lib.h>
 #include <GNUnet/gnunet_fsui_lib.h>
+#include <GNUnet/gnunet_uritrack_lib.h>
 #include "gnunetgtk_common.h"
 
 /**
  * On search box, for namespace selection
  * (for input of search URI; lists known namespaces).
  */
-enum {
+enum
+{
   NS_SEARCH_DESCRIPTION = 0,
   NS_SEARCH_ENCNAME,
   NS_SEARCH_METADATA,
@@ -47,7 +49,8 @@ enum {
  * For listing of search results for main search.
  * Represents a search result.
  */
-enum {
+enum
+{
   SEARCH_NAME = 0,
   SEARCH_SIZE,
   SEARCH_HSIZE,
@@ -67,7 +70,8 @@ enum {
  * Search entry in search summary list.
  * Represents a search process.
  */
-enum {
+enum
+{
   SEARCH_SUMMARY_NAME = 0,
   SEARCH_SUMMARY_RESULT_COUNT,
   SEARCH_SUMMARY_INTERNAL,
@@ -77,18 +81,20 @@ enum {
 /**
  * Entry in download summary.
  */
-enum {
+enum
+{
   DOWNLOAD_FILENAME = 0,
   DOWNLOAD_SHORTNAME,
   DOWNLOAD_SIZE,
   DOWNLOAD_HSIZE,
   DOWNLOAD_PROGRESS,
   DOWNLOAD_URISTRING,
-  DOWNLOAD_INTERNAL, /* struct DL */
+  DOWNLOAD_INTERNAL,            /* struct DL */
   DOWNLOAD_NUM
 };
 
-enum {
+enum
+{
   NAMESPACE_FILENAME = 0,
   NAMESPACE_SIZE,
   NAMESPACE_HSIZE,
@@ -98,7 +104,8 @@ enum {
   NAMESPACE_NUM
 };
 
-enum {
+enum
+{
   IN_NAMESPACE_FILENAME = 0,
   IN_NAMESPACE_SIZE,
   IN_NAMESPACE_HSIZE,
@@ -116,7 +123,8 @@ enum {
 /**
  * Entry in upload summary.
  */
-enum {
+enum
+{
   UPLOAD_FILENAME = 0,
   UPLOAD_PROGRESS,
   UPLOAD_URISTRING,
@@ -124,14 +132,16 @@ enum {
   UPLOAD_NUM
 };
 
-enum {
+enum
+{
   META_TYPE = 0,
   META_STYPE,
   META_VALUE,
   META_NUM,
 };
 
-enum {
+enum
+{
   KTYPE_STRING = 0,
   KTYPE_TYPE,
   KTYPE_NUM,
@@ -141,62 +151,63 @@ enum {
 /**
  * @brief linked list of pages in the search notebook
  */
-typedef struct SL {
-  struct SL * next;
+typedef struct SL
+{
+  struct SL *next;
   /**
    * Reference to the glade XML context that was
    * used to create the search page.
    */
-  GladeXML * searchXML;
+  GladeXML *searchXML;
 
   /**
    * Reference to the glade XML context that was
    * used to create the search label.
    */
-  GladeXML * labelXML;
+  GladeXML *labelXML;
 
   /**
    * Tree view widget that is used to display the
    * search results.
    */
-  GtkTreeView * treeview;
+  GtkTreeView *treeview;
 
   /**
    * Model of the tree view.
    */
-  GtkTreeStore * tree;
+  GtkTreeStore *tree;
 
   /**
    * The label used in the notebook page.
    */
-  GtkWidget * tab_label;
+  GtkWidget *tab_label;
 
   /**
    * The notebook page that is associated with this
    * search.
    */
-  GtkWidget * searchpage;
+  GtkWidget *searchpage;
 
   /**
    * Path to the entry in the summary list
    * for this search.
    */
-  GtkTreeRowReference * summaryViewRowReference;
+  GtkTreeRowReference *summaryViewRowReference;
 
   /**
    * URI for this search.
    */
-  struct ECRS_URI * uri;
+  struct ECRS_URI *uri;
 
   /**
    * String describing the search.
    */
-  char * searchString;
+  char *searchString;
 
   /**
    * FSUI search handle.
    */
-  struct FSUI_SearchList * fsui_list;
+  struct FSUI_SearchList *fsui_list;
 
   /**
    * Number of results received so far.
@@ -210,35 +221,36 @@ typedef struct SL {
 
   /**
    * Y-coordinate of the last right-click in the search list.
-   */ 
+   */
   unsigned int last_y;
 
 } SearchList;
 
 
-typedef struct DL {
-  struct DL * next;
+typedef struct DL
+{
+  struct DL *next;
 
   /**
    * URI of the download.
    */
-  struct ECRS_URI * uri;
+  struct ECRS_URI *uri;
 
   /**
    * Where is the download being saved to?
    */
-  char * filename;
+  char *filename;
 
   /**
    * Path in the summary view for this download.
    */
-  GtkTreeRowReference * summaryViewRowReference;
+  GtkTreeRowReference *summaryViewRowReference;
 
   /**
    * Search that this download belongs to.
    * Maybe NULL.
    */
-  struct SL * searchList;
+  struct SL *searchList;
 
   /**
    * Path in the search view that this
@@ -246,12 +258,12 @@ typedef struct DL {
    * if search has been closed or if download
    * was initiated from URI without search.
    */
-  GtkTreeRowReference * searchViewRowReference;
+  GtkTreeRowReference *searchViewRowReference;
 
   /**
    * FSUI reference for the download.
    */
-  struct FSUI_DownloadList * fsui_list;
+  struct FSUI_DownloadList *fsui_list;
 
   /**
    * Total size of the download.
@@ -267,25 +279,26 @@ typedef struct DL {
 
 } DownloadList;
 
-typedef struct UL {
-  struct UL * next;
+typedef struct UL
+{
+  struct UL *next;
 
   /**
    * Which file or directory are we uploading?
    */
-  char * filename;
+  char *filename;
 
   /**
    * Path in the summary view for this download.
    */
-  GtkTreeRowReference * summaryViewRowReference;
+  GtkTreeRowReference *summaryViewRowReference;
 
-  struct FSUI_UploadList * fsui_list;
+  struct FSUI_UploadList *fsui_list;
 
   /**
    * Set to final URI upon successful completion.
    */
-  struct ECRS_URI * uri;
+  struct ECRS_URI *uri;
 
   /**
    * Total size of the upload.
@@ -294,24 +307,29 @@ typedef struct UL {
 
   int has_terminated;
 
+  int is_top;
+
 } UploadList;
 
-extern struct FSUI_Context * ctx;
+extern struct FSUI_Context *ctx;
 
-extern struct GE_Context * ectx;
+extern struct GE_Context *ectx;
 
-extern struct GC_Configuration * cfg;
+extern struct GC_Configuration *cfg;
 
-extern SearchList * search_head;
+extern SearchList *search_head;
 
-extern DownloadList * download_head;
+extern DownloadList *download_head;
 
-extern UploadList * upload_head;
+extern UploadList *upload_head;
 
-extern GtkListStore * search_summary;
+extern GtkListStore *search_summary;
 
-extern GtkTreeStore * download_summary;
+extern GtkTreeStore *download_summary;
+
+extern GtkTreeStore *upload_summary;
+
+const char *getColorCode (enum URITRACK_STATE state);
 
-extern GtkTreeStore * upload_summary;
 
 #endif
